test suite reviews and discussions
 help / color / mirror / Atom feed
* [dts] [PATCH V2] tests/vf_kernel:modify default driver from igb_uio to vfio-pci on vm
@ 2020-08-13  7:06 Xie wei
  2020-08-21  2:41 ` Tu, Lijuan
  0 siblings, 1 reply; 2+ messages in thread
From: Xie wei @ 2020-08-13  7:06 UTC (permalink / raw)
  To: dts; +Cc: Xie wei

modify vm default driver from igb_uio to vfio-pci

Signed-off-by: Xie wei <weix.xie@intel.com>
---
 tests/TestSuite_vf_kernel.py | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/tests/TestSuite_vf_kernel.py b/tests/TestSuite_vf_kernel.py
index f2f28fe..54676c2 100755
--- a/tests/TestSuite_vf_kernel.py
+++ b/tests/TestSuite_vf_kernel.py
@@ -706,7 +706,7 @@ class TestVfKernel(TestCase):
         """
         self.vm0_dut.send_expect("ifconfig %s up " % self.vm0_intf0, "#")
         self.vm0_dut.send_expect("ifconfig %s up " % self.vm0_intf1, "#")
-        self.vm0_dut.ports_info[1]['port'].bind_driver('igb_uio')
+        self.vm0_dut.ports_info[1]['port'].bind_driver('vfio-pci')
 
         # because of alt_session is false, host cmd need to execute before testpmd start
         vm0_vf0_mac = self.vm0_dut.ports_info[0]['port'].get_mac_addr()
@@ -790,11 +790,11 @@ class TestVfKernel(TestCase):
             self.verify(self.check_pf_vf_link_status(
                 self.vm1_dut, vm1_intf), "VM1_vf: %s link down" % vm1_intf)
 
         # Bind kernel VF0, VF1 to igb_uio in VM0, bind kernel VF4 to igb_uio in
         # VM1
-        self.vm0_dut.ports_info[0]['port'].bind_driver('igb_uio')
-        self.vm0_dut.ports_info[1]['port'].bind_driver('igb_uio')
-        self.vm1_dut.ports_info[0]['port'].bind_driver('igb_uio')
+        self.vm0_dut.ports_info[0]['port'].bind_driver('vfio-pci')
+        self.vm0_dut.ports_info[1]['port'].bind_driver('vfio-pci')
+        self.vm1_dut.ports_info[0]['port'].bind_driver('vfio-pci')
 
         # because of alt_session is false, host cmd need to execute before testpmd start
         vm0_vf2_mac = self.vm0_dut.ports_info[2]['port'].get_mac_addr()
@@ -790,11 +790,11 @@ class TestVfKernel(TestCase):
                 self.vm1_dut, vm1_intf), "VM1_vf: %s link down" % vm1_intf)
 
-        # Bind kernel VF0, VF1 to igb_uio in VM0, bind kernel VF4 to igb_uio in
+        # Bind kernel VF0, VF1 to vfio-pci in VM0, bind kernel VF4 to vfio-pci in
         # VM1
-- 
2.17.1


^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: [dts] [PATCH V2] tests/vf_kernel:modify default driver from igb_uio to vfio-pci on vm
  2020-08-13  7:06 [dts] [PATCH V2] tests/vf_kernel:modify default driver from igb_uio to vfio-pci on vm Xie wei
@ 2020-08-21  2:41 ` Tu, Lijuan
  0 siblings, 0 replies; 2+ messages in thread
From: Tu, Lijuan @ 2020-08-21  2:41 UTC (permalink / raw)
  To: Xie, WeiX, dts; +Cc: Xie, WeiX

> modify vm default driver from igb_uio to vfio-pci
> 
> Signed-off-by: Xie wei <weix.xie@intel.com>

Applied

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2020-08-21  2:41 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2020-08-13  7:06 [dts] [PATCH V2] tests/vf_kernel:modify default driver from igb_uio to vfio-pci on vm Xie wei
2020-08-21  2:41 ` Tu, Lijuan

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).